/*
 *  Apache2::WebApp::Toolkit - Admin Control Panel (page.css)
 *  Copyright (C) 2010 Marc S. Brooks <mbrooks@cpan.org>
 *
 *  Licensed under the terms of the BSD License
 *  http://www.opensource.org/licenses/bsd-license.php
 */

/*--------------------------------------------------------------------------*/
/* page - container                                                         */

#page {
	clear: both;
	left: -4px;
	position: relative;
}

#page a:hover {
	background-color: transparent;
}


/* page - title text */

#page h2.title {
	font-weight: bold;
}

#page h2.title {
	font-size: 20px;
	padding: 3px;
}


/* page - back */

#page div.back {
	float: right;
	position: relative;
}

#page div.back a {
	background-image: url( /extras/admin/images/back.gif );
	background-repeat: no-repeat;
	display: block;
	height: 24px;
	padding-left: 35px;
	padding-top: 4px;
	text-align: right;
}


/* page - print */

#page div.print {
	float: right;
}

#page div.print a {
	background-image: url( /extras/admin/images/print.gif );
	background-repeat: no-repeat;
	display: block;
	height: 24px;
	padding-left: 35px;
	padding-top: 4px;
	text-align: right;
}
